@@ -4,7 +4,7 @@ import pandas as pd
 import psycopg2 as pgsql
 from pydantic import Field, SecretStr, constr, create_model
 
-from toucan_connectors.common import adapt_param_type
+from toucan_connectors.common import adapt_param_type, convert_to_printf_templating_style
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource, strlist_to_enum
 
 
@@ -113,7 +113,8 @@ class PostgresConnector(ToucanConnector):
         connection = pgsql.connect(**self.get_connection_params(database=data_source.database))
 
         query_params = data_source.parameters or {}
-        df = pd.read_sql(data_source.query, con=connection, params=adapt_param_type(query_params))
+        query = convert_to_printf_templating_style(data_source.query)
+        df = pd.read_sql(query, con=connection, params=adapt_param_type(query_params))
 
         connection.close()
 
