@@ -2,6 +2,7 @@ import pandas as pd
 import pyhdb
 from pydantic import Field, SecretStr, constr
 
+from toucan_connectors.common import convert_to_printf_templating_style
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
 
 
@@ -33,7 +34,8 @@ class SapHanaConnector(ToucanConnector):
             self.host, self.port, self.user, self.password.get_secret_value()
         )
 
-        df = pd.read_sql(data_source.query, con=connection)
+        query = convert_to_printf_templating_style(data_source.query)
+        df = pd.read_sql(query, con=connection)
 
         connection.close()
 
